@@ -1,5 +1,6 @@
 import subprocess
 
+from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.bucket_store.bucket_storage import bucketCrud
 
 class BucketRouting:
@@ -17,7 +18,7 @@ class BucketRouting:
                         try:
                             bucket_operations.add_bucket()
                         except KeyboardInterrupt:
-                            print("\n")
+                            Py_version_manager.py_print(" ")
 
         elif self.arguments.bucket_commands == 'delete':
             bucket_operations = bucketCrud(alias=self.arguments.alias)
@@ -25,7 +26,7 @@ class BucketRouting:
                         try:
                             bucket_operations.delete_bucket()
                         except KeyboardInterrupt:
-                            print("\n")
+                            Py_version_manager.py_print(" ")
         
         elif self.arguments.bucket_commands == 'list':
             bucket_operations = bucketCrud(alias=self.arguments.alias)
@@ -33,6 +34,6 @@ class BucketRouting:
                         try:
                             bucket_operations.list_bucket()
                         except KeyboardInterrupt:
-                            print("\n")
+                            Py_version_manager.py_print(" ")
 
 
