@@ -1,5 +1,8 @@
 import json
 import os
+import platform
+
+from e2e_cli.core.py_manager import Py_version_manager
 
 class AliasServices:
     def __init__(self, alias):
@@ -15,11 +18,16 @@ class AliasServices:
         else:
             return {"message": "Invalid alias provided"}
 
+def system_file():
+    if platform.system() == "Windows":  
+                return os.path.expanduser("~") + '\.E2E_CLI\config.json'
+    elif platform.system() == "Linux" or platform.system() == "Mac":  
+                return os.path.expanduser("~") + '/.E2E_CLI/config.json'
 
 
 def get_user_cred(name, x=0):
-        
-    file= os.path.expanduser("~") + '/.E2E_CLI/config.json'
+    
+    file= system_file()
 
     # Opening JSON file
     f = open(file)
@@ -37,13 +45,13 @@ def get_user_cred(name, x=0):
     if(name in data):
         return[ data[name]['api_auth_token'], data[name]['api_key'] ]
     else:
-        print("the given alias/credential doesn't exist")
+        Py_version_manager.py_print("the given alias/credential doesn't exist")
         return None
 
 
-def check_user_cred(name, x=0):
+def check_user_cred(name):
         
-    file= os.path.expanduser("~") + '/.E2E_CLI/config.json'
+    file= system_file()
 
     # Opening JSON file
     f = open(file)
