@@ -1,5 +1,6 @@
 import subprocess
 
+from e2e_cli.core.py_manager import Py_version_manager 
 from e2e_cli.loadbalancer.lb import LBClass
 
 
@@ -16,7 +17,7 @@ class LBRouting:
             try:
                lb_class_object.create_lb()
             except KeyboardInterrupt:
-                print("\n")
+                Py_version_manager.py_print(" ")
                 pass
 
         elif self.arguments.lb_commands == 'list' or self.arguments.lb_commands == 'ls':
@@ -24,7 +25,7 @@ class LBRouting:
             try:
                lb_class_object.list_lb()
             except KeyboardInterrupt:
-                print("\n")
+                Py_version_manager.py_print(" ")
                 pass
 
         elif self.arguments.lb_commands == 'delete':
@@ -32,7 +33,7 @@ class LBRouting:
             try:
                lb_class_object.delete_lb()
             except KeyboardInterrupt:
-                print("\n")
+                Py_version_manager.py_print(" ")
                 pass
 
         elif self.arguments.lb_commands == 'edit':
@@ -40,5 +41,5 @@ class LBRouting:
             try:
                lb_class_object.edit_lb()
             except KeyboardInterrupt:
-                print("\n")
+                Py_version_manager.py_print(" ")
                 pass
