@@ -30,7 +30,7 @@ class LBServices:
 
         if table.rowcount == 0:
             return "/"
-        print(table)
+        Py_version_manager.py_print(table)
         node_choice = int(Py_version_manager.py_input("Enter the Node ID: "))
         return node_choice
 
@@ -47,8 +47,8 @@ class LBServices:
         node_choice = self.choice_nodes(nodes_assigned_to_lb, node_list_dict)
         if node_choice == '/':
             return nodes_assigned_to_lb
-        print("Node name: ", node_list_dict[node_choice]["name"])
-        print("Node ip: ", node_list_dict[node_choice]["public_ip_address"])
+        Py_version_manager.py_print("Node name: ", node_list_dict[node_choice]["name"])
+        Py_version_manager.py_print("Node ip: ", node_list_dict[node_choice]["public_ip_address"])
         node_port = Py_version_manager.py_input("Enter the Node Port: ")
         nodes_assigned_to_lb.append(
             {"backend_name": node_list_dict[node_choice]["name"],
@@ -58,8 +58,8 @@ class LBServices:
             node_choice = self.choice_nodes(nodes_assigned_to_lb, node_list_dict)
             if node_choice == '/':
                 break
-            print("Node name: ", node_list_dict[node_choice]["name"])
-            print("Node ip: ", node_list_dict[node_choice]["private_ip_address"])
+            Py_version_manager.py_print("Node name: ", node_list_dict[node_choice]["name"])
+            Py_version_manager.py_print("Node ip: ", node_list_dict[node_choice]["private_ip_address"])
             node_port = Py_version_manager.py_input("Enter the Node Port: ")
             nodes_assigned_to_lb.append(
                 {"backend_name": node_list_dict[node_choice]["name"],
@@ -69,13 +69,13 @@ class LBServices:
         return nodes_assigned_to_lb
 
     def classic_lb_creation(self, api_key, auth_token, nodes_assigned_to_lb, plan_assigned_to_lb):
-        print("(Note: All the fields having a important ahead of them can't be skipped)")
+        Py_version_manager.py_print("(Note: All the fields having a important ahead of them can't be skipped)")
         name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ")
-        print("\n\nLoad Balancing Property: ")
+        Py_version_manager.py_print("  Load Balancing Property: ")
         lb_balancing_property = {"1": "source",
                                  "2": "roundrobin"}
-        print("1. Source IP Hash")
-        print("2. Round Robin")
+        Py_version_manager.py_print("1. Source IP Hash")
+        Py_version_manager.py_print("2. Round Robin")
         lb_balancing_property_choice = Py_version_manager.py_input(": ")
         balancing_property_assigned_to_lb = lb_balancing_property[lb_balancing_property_choice]
 
@@ -122,7 +122,7 @@ class LBServices:
         table.add_row(["7", "Suffix Match(Case-Sensitive)"])
         table.add_row(["8", "Regex Match(Case-Sensitive)"])
 
-        print(table)
+        Py_version_manager.py_print(table)
         acl_conditions = []
         acl_condition_choice = Py_version_manager.py_input(": ")
         if acl_condition_choice == "1":
@@ -156,7 +156,7 @@ class LBServices:
         table.add_row(["3", "Suffix Match"])
         table.add_row(["4", "Regex Match"])
 
-        print(table)
+        Py_version_manager.py_print(table)
         acl_condition_choice = Py_version_manager.py_input(": ")
         acl_conditions = []
         if acl_condition_choice == "1":
@@ -186,7 +186,7 @@ class LBServices:
         table.add_row(["7", "Suffix Match(Case-Sensitive)"])
         table.add_row(["8", "Regex Match(Case-Sensitive)"])
 
-        print(table)
+        Py_version_manager.py_print(table)
         acl_conditions = []
         acl_condition_choice = Py_version_manager.py_input(": ")
         if acl_condition_choice == "1":
@@ -232,7 +232,7 @@ class LBServices:
         table.add_row(["7", "CONNECT"])
         table.add_row(["8", "TRACE"])
 
-        print(table)
+        Py_version_manager.py_print(table)
         acl_conditions = []
         acl_conditions.append("method")
         acl_condition_choice = Py_version_manager.py_input(": ")
@@ -265,11 +265,11 @@ class LBServices:
         return acl_conditions
 
     def set_acl_rules(self, rule_count):
-        print("\n\nACL Rules")
+        Py_version_manager.py_print(" ACL Rules")
         acl_instance = dict()
         acl_instance["acl_name"] = "rule-" + str(rule_count)
-        print("Name     " + acl_instance["acl_name"])
-        print("Condition\n")
+        Py_version_manager.py_print("Name     " + acl_instance["acl_name"])
+        Py_version_manager.py_print("Condition ")
         table = PrettyTable(["ID", "CONDITIONS"])
         table.add_row(["1", "PATH BASED"])
         table.add_row(["2", "HOST BASED"])
@@ -277,7 +277,7 @@ class LBServices:
         table.add_row(["4", "HTTP METHODS BASED"])
         table.add_row(["5", "SOURCE IP BASED"])
 
-        print(table)
+        Py_version_manager.py_print(table)
         condition_choice = Py_version_manager.py_input(": ")
         if condition_choice == "1":
             condition_acl_list = self.acl_condition_path()
@@ -312,11 +312,11 @@ class LBServices:
         return acl_rules_assigned
 
     def backends(self, api_key, auth_token, backends_assigned_to_lb, nodes_assigned_to_backend):
-        print("Load Balancing Property: ")
+        Py_version_manager.py_print("Load Balancing Property: ")
         lb_balancing_property = {"1": "source",
                                  "2": "roundrobin"}
-        print("1. Source IP Hash")
-        print("2. Round Robin")
+        Py_version_manager.py_print("1. Source IP Hash")
+        Py_version_manager.py_print("2. Round Robin")
         prev_len = len(backends_assigned_to_lb)
         lb_balancing_property_choice = Py_version_manager.py_input(": ")
         backends_assigned_to_lb.append({"balance": lb_balancing_property[lb_balancing_property_choice],
@@ -414,19 +414,19 @@ class LBServices:
                 table.add_row([backend_instance["backend_id"], backend_instance["backend_name"]])
         if table.rowcount == 0:
             return "/"
-        print(table)
+        Py_version_manager.py_print(table)
         backend_choice = Py_version_manager.py_input(": ")
         return backend_choice
 
     def select_rules(self, acl_rules):
-        print("Choose a rule ")
+        Py_version_manager.py_print("Choose a rule ")
         rules_object_list = self.create_rules_objects(acl_rules)
         table = PrettyTable(["ID", "ACL RULE", "ACL RULE TYPE"])
         rule_id = 1
         for rule_instance in rules_object_list:
             table.add_row([rule_id, rule_instance["rule"], rule_instance["rule_type"]])
             rule_id += 1
-        print(table)
+        Py_version_manager.py_print(table)
         rule_choice = Py_version_manager.py_input(": ")
         return rules_object_list[int(rule_choice) - 1]["rule"]
 
@@ -478,7 +478,7 @@ class LBServices:
 
     def advance_lb_creation(self, api_key, auth_token, acl_rules_assigned_to_lb, acl_maps_to_backends,
                             backends_assigned_to_lb, plan_assigned_to_lb):
-        print("(Note: All the fields having a important ahead of them can't be skipped)")
+        Py_version_manager.py_print("(Note: All the fields having a important ahead of them can't be skipped)")
         name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ")
         acl_rules_assigned_to_lb = self.acl_rules(acl_rules_assigned_to_lb)
         if not backends_assigned_to_lb:
@@ -488,11 +488,11 @@ class LBServices:
                 backends_assigned_to_lb = self.backends(api_key, auth_token, backends_assigned_to_lb, [])
                 add_more_backend = Py_version_manager.py_input("Want to add more backend(y/n): ")
         else:
-            print("Choose Backend you want to edit")
+            Py_version_manager.py_print("Choose Backend you want to edit")
             table = PrettyTable(["Backend Server"])
             for backend_instance in backends_assigned_to_lb:
                 table.add_row(backend_instance["name"])
-            print(table)
+            Py_version_manager.py_print(table)
             backend_choice = Py_version_manager.py_input(": ")
             backends_assigned_to_lb = self.backends(api_key, auth_token, backends_assigned_to_lb,
                                                     backends_assigned_to_lb[int(backend_choice)]["servers"])
@@ -542,10 +542,10 @@ class LBServices:
         if api_key_credentials_object["message"] == "Invalid alias provided":
             return api_key_credentials_object
         else:
-            print("Fill in the details required")
-            print("Choose the type of Load Balancer you want to use: ")
-            print("1. Classic Load Balancer")
-            print("2. Advanced Load Balancer")
+            Py_version_manager.py_print("Fill in the details required")
+            Py_version_manager.py_print("Choose the type of Load Balancer you want to use: ")
+            Py_version_manager.py_print("1. Classic Load Balancer")
+            Py_version_manager.py_print("2. Advanced Load Balancer")
             choice_of_lb = Py_version_manager.py_input(": ")
             lb_plans = [
                 {
@@ -579,12 +579,12 @@ class LBServices:
                     "Price": " Rs16 /hour or  Rs11680 /mo"
                 }
             ]
-            print("Plans for load-balancers")
+            Py_version_manager.py_print("Plans for load-balancers")
             table = PrettyTable(["ID", "Plan", "Specs", "Price"])
             for plan_instance in lb_plans:
                 table.add_row([plan_instance["ID"], plan_instance["Plan"],
                                plan_instance["Specs"], plan_instance["Price"]])
-            print(table)
+            Py_version_manager.py_print(table)
             plan_choice = int(Py_version_manager.py_input(": "))
             plan_assigned_to_lb = lb_plans[plan_choice-1]["Plan"]
             if int(choice_of_lb) == 1:
@@ -614,10 +614,10 @@ class LBServices:
         lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
         all_lb_in_list = self.get_lb_by_id(lb_id)
         while all_lb_in_list is None:
-            print("Please choose a valid load-balancer id: ")
+            Py_version_manager.py_print("Please choose a valid load-balancer id: ")
             lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
             all_lb_in_list = self.get_lb_by_id(lb_id)
-        print("Deleting this lb instance can cause loss!")
+        Py_version_manager.py_print("Deleting this lb instance can cause loss!")
         choice = Py_version_manager.py_input("Do you still want to continue?(Y/N)")
         if choice.upper() == "Y":
             api_key_credentials_object = self.alias_service_object.get_api_credentials()
@@ -638,7 +638,7 @@ class LBServices:
             return {"message": "Failure"}
 
     def change_lb_name(self):
-        lb_name = Py_version_manager.py_input("\nEnter Load-Balancer Name: ")
+        lb_name = Py_version_manager.py_input(" Enter Load-Balancer Name: ")
         payload = {"name": lb_name,
                    "type": "rename"}
 
@@ -648,7 +648,7 @@ class LBServices:
         table = PrettyTable(["Backend ID", "Backend Name"])
         for backend_index in range(0, len(backend_assigned)):
             table.add_row([str(backend_index + 1), "backend-server-" + str(backend_index + 1)])
-        print(table)
+        Py_version_manager.py_print(table)
         backend_choice = Py_version_manager.py_input(": ")
         return backend_choice
 
@@ -656,7 +656,7 @@ class LBServices:
         table = PrettyTable(["Node ID", "Node Name"])
         for node_index in range(0, len(nodes_assigned)):
             table.add_row([str(node_index + 1), nodes_assigned[node_index]["backend_name"]])
-        print(table)
+        Py_version_manager.py_print(table)
         node_choice = Py_version_manager.py_input(": ")
         return node_choice
 
@@ -665,18 +665,18 @@ class LBServices:
         backend_assigned = appliances_assigned["context"]["backends"]
         backend_choice = self.select_backend(backend_assigned)
         nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-        print("\n")
+        Py_version_manager.py_print(" ")
         node_choice = self.select_node(nodes_assigned)
-        node_port = Py_version_manager.py_input("\nNode Port: ")
+        node_port = Py_version_manager.py_input(" Node Port: ")
         nodes_assigned[int(node_choice) - 1]["backend_port"] = node_port
         change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
         while change_choice.lower() == 'y':
             backend_assigned = appliances_assigned["context"]["backends"]
             backend_choice = self.select_backend(backend_assigned)
             nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-            print("\n")
+            Py_version_manager.py_print(" ")
             node_choice = self.select_node(nodes_assigned)
-            node_port = Py_version_manager.py_input("\nNode Port: ")
+            node_port = Py_version_manager.py_input(" Node Port: ")
             nodes_assigned[int(node_choice) - 1]["backend_port"] = node_port
             change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
         payloads = {
@@ -704,7 +704,7 @@ class LBServices:
         backend_assigned = appliances_assigned["context"]["backends"]
         backend_choice = self.select_backend(backend_assigned)
         nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-        print("\n")
+        Py_version_manager.py_print(" ")
         nodes_assigned = self.assign_nodes(nodes_assigned, api_credentials_object["api_credentials"]["api_key"],
                                            api_credentials_object["api_credentials"]["api_auth_token"])
         change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
@@ -712,7 +712,7 @@ class LBServices:
             backend_assigned = appliances_assigned["context"]["backends"]
             backend_choice = self.select_backend(backend_assigned)
             nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-            print("\n")
+            Py_version_manager.py_print(" ")
             nodes_assigned = self.assign_nodes(nodes_assigned, api_credentials_object["api_credentials"]["api_key"],
                                                api_credentials_object["api_credentials"]["api_auth_token"])
             change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
@@ -744,13 +744,13 @@ class LBServices:
             lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
             all_lb_in_list = self.get_lb_by_id(lb_id)
             while all_lb_in_list is None:
-                print("Please choose a valid load-balancer id: ")
+                Py_version_manager.py_print("Please choose a valid load-balancer id: ")
                 lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
                 all_lb_in_list = self.get_lb_by_id(lb_id)
-            print("\n\nPlease Make a Choice ")
-            print("1.  Change LoadBalancer Name")
-            print("2.  Change a Port of a Node")
-            print("3.  Add a new Port")
+            Py_version_manager.py_print("  Please Make a Choice ")
+            Py_version_manager.py_print("1.  Change LoadBalancer Name")
+            Py_version_manager.py_print("2.  Change a Port of a Node")
+            Py_version_manager.py_print("3.  Add a new Port")
             edit_choice = Py_version_manager.py_input(": ")
             if edit_choice == str(1):
                 json_payload = self.change_lb_name()
