@@ -1,5 +1,6 @@
 import subprocess
 
+from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.node.node import NodeCrud
 
 class NodeRouting:
@@ -17,7 +18,7 @@ class NodeRouting:
                         try:
                            Node_operations.add_node()
                         except KeyboardInterrupt:
-                            print("\n")   
+                            Py_version_manager.py_print(" ")   
 
         elif self.arguments.node_commands == 'delete':
             Node_operations = NodeCrud(alias=self.arguments.alias)
@@ -25,7 +26,7 @@ class NodeRouting:
                         try:
                            Node_operations.delete_node()
                         except KeyboardInterrupt:
-                            print("\n")
+                            Py_version_manager.py_print(" ")
 
         elif self.arguments.node_commands == 'get':
             Node_operations = NodeCrud(alias=self.arguments.alias)
@@ -33,7 +34,7 @@ class NodeRouting:
                         try:
                            Node_operations.get_node_by_id()
                         except:
-                            print("\n")   
+                            Py_version_manager.py_print(" ")   
         
         elif self.arguments.node_commands == 'list':
             Node_operations = NodeCrud(alias=self.arguments.alias)
@@ -41,6 +42,6 @@ class NodeRouting:
                         try: 
                            Node_operations.list_node()
                         except KeyboardInterrupt:
-                            print("\n")   
+                            Py_version_manager.py_print(" ")   
 
 
